complete -c cargo-sonar -l audit-path -d 'Path of the \'cargo audit\' report' -r -F
complete -c cargo-sonar -l clippy-path -d 'Path of the \'cargo clippy\' report' -r -F
complete -c cargo-sonar -l deny-path -d 'Path of the \'cargo deny\' report' -r -F
complete -c cargo-sonar -l outdated-path -d 'Path of the \'cargo outdated\' report' -r -F
complete -c cargo-sonar -l udeps-path -d 'Path of the \'cargo udeps\' report' -r -F
complete -c cargo-sonar -l sonar-path -d 'Path to the generated sonar report' -r -F
complete -c cargo-sonar -l codeclimate-path -d 'Path to the generated codeclimate report' -r -F
complete -c cargo-sonar -l completion -d 'Generate completion rules for some shells' -r -f -a "{bash\t'Bourne Again SHell (bash)',elvish\t'Elvish shell',fish\t'Friendly Interactive SHell (fish)',nushell\t'Nushell',power-shell\t'PowerShell',zsh\t'Z SHell (zsh)'}"
complete -c cargo-sonar -l audit -d 'Enable parsing of the \'cargo audit\' report'
complete -c cargo-sonar -l clippy -d 'Enable parsing of the \'cargo clippy\' report'
complete -c cargo-sonar -l deny -d 'Enable parsing of the \'cargo deny\' report'
complete -c cargo-sonar -l outdated -d 'Enable parsing of the \'cargo outdated\' report'
complete -c cargo-sonar -l udeps -d 'Enable parsing of the \'cargo udeps\' report'
complete -c cargo-sonar -s h -l help -d 'Print help (see more with \'--help\')'
complete -c cargo-sonar -s V -l version -d 'Print version'
